@@ -5,8 +5,12 @@
 #include "narray.h"
 #include<string.h>
 
+/* for compatibility with ruby 1.6 */
 #ifndef RSTRING_PTR
-#  define RSTRING_PTR(s) (RSTRING(s)->ptr)
+#define RSTRING_PTR(s) (RSTRING(s)->ptr)
+#endif
+#ifndef SafeStringValue
+#define SafeStringValue(s) Check_SafeStr(s)
 #endif
 
 static VALUE rb_eHE5Error;
@@ -78,7 +82,7 @@ HE5Wrap_store_NArray1D_or_str(int ntype, VALUE obj, void **ptr){
     case  HE5T_CHARSTRING:
         switch (TYPE(obj)){
         case T_STRING:
-          Check_SafeStr(obj);
+          SafeStringValue(obj);
           *ptr = (char *) RSTRING_PTR(obj);
           break;
         case T_ARRAY:
