@@ -5,8 +5,12 @@
 #include "narray.h"
 #include<string.h>
 
+/* for compatibility with ruby 1.6 */
 #ifndef RSTRING_PTR
-#  define RSTRING_PTR(s) (RSTRING(s)->ptr)
+#define RSTRING_PTR(s) (RSTRING(s)->ptr)
+#endif
+#ifndef SafeStringValue
+#define SafeStringValue(s) Check_SafeStr(s)
 #endif
 
 extern int   check_numbertype(char *);
@@ -541,7 +545,7 @@ hdfeos5_ptcreate(VALUE mod, VALUE pointname)
     file=he5file->name;
 
     Check_Type(pointname,T_STRING);
-    Check_SafeStr(pointname);
+    SafeStringValue(pointname);
     i_pointname = RSTRING_PTR(pointname);
 
     ptid = HE5_PTcreate(i_fid, i_pointname);
@@ -567,7 +571,7 @@ hdfeos5_ptattach(VALUE mod, VALUE pointname)
     i_fname=he5file->name;
 
     Check_Type(pointname,T_STRING);
-    Check_SafeStr(pointname);
+    SafeStringValue(pointname);
     i_pointname = RSTRING_PTR(pointname);
 
     ptid = HE5_PTattach(i_fid, i_pointname);
@@ -753,7 +757,7 @@ hdfeos5_ptdeflevel(VALUE file, VALUE levelname, VALUE nfields, VALUE rank, VALUE
 
     i_nfields=NUM2INT(nfields);
     Check_Type(levelname,T_STRING);
-    Check_SafeStr(levelname);
+    SafeStringValue(levelname);
     i_levelname = RSTRING_PTR(levelname);
 
     i_rank=ALLOCA_N(int,i_nfields*sizeof(int));
@@ -761,14 +765,14 @@ hdfeos5_ptdeflevel(VALUE file, VALUE levelname, VALUE nfields, VALUE rank, VALUE
     i_rank = hdfeos5_obj2cintary(rank);
 
     Check_Type(fieldlist,T_STRING);
-    Check_SafeStr(fieldlist);
+    SafeStringValue(fieldlist);
     i_fieldlist = RSTRING_PTR(fieldlist);
 
     dimlist = rb_Array(dimlist);
     i_dimlist = hdfeos5_obj2clongary(dimlist);
 
     Check_Type(datatype,T_STRING);
-    Check_SafeStr(datatype);
+    SafeStringValue(datatype);
     i_datatype = RSTRING_PTR(datatype);
     nn = HE5_EHparsestr(i_datatype, ',', pntr, slen);
     i_array = ALLOCA_N(int, i_nfields);
@@ -806,13 +810,13 @@ hdfeos5_ptdeflinkage(VALUE file, VALUE parent_level, VALUE child_level,VALUE lin
     i_ptid=he5point->ptid;
 
     Check_Type(parent_level,T_STRING);
-    Check_SafeStr(parent_level);
+    SafeStringValue(parent_level);
     i_parent_level = RSTRING_PTR(parent_level);
     Check_Type(child_level,T_STRING);
-    Check_SafeStr(child_level);
+    SafeStringValue(child_level);
     i_child_level = RSTRING_PTR(child_level);
     Check_Type(linklevel,T_STRING);
-    Check_SafeStr(linklevel);
+    SafeStringValue(linklevel);
     i_linklevel = RSTRING_PTR(linklevel);
 
     o_rtn_val = HE5_PTdeflinkage(i_ptid, i_parent_level, i_child_level, i_linklevel);
@@ -825,7 +829,7 @@ hdfeos5_ptwritelevel(VALUE mod, VALUE count, VALUE data, VALUE ntype)
 {
     char *chk_ntype;
     Check_Type(ntype,T_STRING);
-    Check_SafeStr(ntype);
+    SafeStringValue(ntype);
     chk_ntype = RSTRING_PTR(ntype);
 
     switch (check_numbertype(chk_ntype)){
@@ -889,9 +893,9 @@ hdfeos5_ptwriteattr(VALUE mod, VALUE attrname, VALUE numbertype, VALUE count, VA
     i_ptid=he5point->ptid;
 
     Check_Type(attrname,T_STRING);
-    Check_SafeStr(attrname);
+    SafeStringValue(attrname);
     Check_Type(numbertype,T_STRING);
-    Check_SafeStr(numbertype);
+    SafeStringValue(numbertype);
     count = rb_Array(count);
 
     i_attrname = RSTRING_PTR(attrname);
@@ -923,7 +927,7 @@ hdfeos5_pt_get_att(VALUE mod, VALUE attrname)
     i_ptid=he5point->ptid;
 
     Check_Type(attrname,T_STRING);
-    Check_SafeStr(attrname);
+    SafeStringValue(attrname);
     i_attrname = RSTRING_PTR(attrname);
 
     o_rtn_val = HE5_PTattrinfo(i_ptid, i_attrname, &o_ntype, &o_count);
@@ -996,7 +1000,7 @@ hdfeos5_ptreadlevel(VALUE mod, VALUE ntype)
 {
     char *chk_ntype;
     Check_Type(ntype,T_STRING);
-    Check_SafeStr(ntype);
+    SafeStringValue(ntype);
     chk_ntype = RSTRING_PTR(ntype);
 
     switch (check_numbertype(chk_ntype)){
@@ -1064,9 +1068,9 @@ hdfeos5_ptinqdatatype(VALUE mod, VALUE levelname, VALUE attrname, VALUE group)
     i_ptid=he5point->ptid;
 
     Check_Type(levelname,T_STRING);
-    Check_SafeStr(levelname);
+    SafeStringValue(levelname);
     Check_Type(attrname,T_STRING);
-    Check_SafeStr(attrname);
+    SafeStringValue(attrname);
 
     i_levelname = RSTRING_PTR(levelname);
     i_attrname = RSTRING_PTR(attrname);
@@ -1158,9 +1162,9 @@ hdfeos5_ptwritegrpattr(VALUE mod, VALUE attrname, VALUE numbertype, VALUE count,
     i_ptid=he5point->ptid;
 
     Check_Type(attrname,T_STRING);
-    Check_SafeStr(attrname);
+    SafeStringValue(attrname);
     Check_Type(numbertype,T_STRING);
-    Check_SafeStr(numbertype);
+    SafeStringValue(numbertype);
     count = rb_Array(count);
 
     i_attrname = RSTRING_PTR(attrname);
@@ -1192,7 +1196,7 @@ hdfeos5_pt_get_grpatt(VALUE mod, VALUE attrname)
     i_ptid=he5point->ptid;
 
     Check_Type(attrname,T_STRING);
-    Check_SafeStr(attrname);
+    SafeStringValue(attrname);
     i_attrname = RSTRING_PTR(attrname);
 
     o_rtn_val = HE5_PTgrpattrinfo(i_ptid, i_attrname, &o_ntype, &o_count);
@@ -1251,9 +1255,9 @@ hdfeos5_ptwritelocattr(VALUE mod, VALUE attrname, VALUE numbertype, VALUE count,
     i_ptid=he5point->ptid;
 
     Check_Type(attrname,T_STRING);
-    Check_SafeStr(attrname);
+    SafeStringValue(attrname);
     Check_Type(numbertype,T_STRING);
-    Check_SafeStr(numbertype);
+    SafeStringValue(numbertype);
     count = rb_Array(count);
 
     i_attrname = RSTRING_PTR(attrname);
@@ -1286,7 +1290,7 @@ hdfeos5_ptfield_get_att(VALUE mod,VALUE  attrname)
     i_levelname=he5point->levelname;
     i_ptid=he5point->ptid;
     Check_Type(attrname,T_STRING);
-    Check_SafeStr(attrname);
+    SafeStringValue(attrname);
     i_attrname = RSTRING_PTR(attrname);
 
     o_rtn_val = HE5_PTlocattrinfo(i_ptid, i_levelname, i_attrname, 
@@ -1406,7 +1410,7 @@ hdfeos5_ptupdatelevel(VALUE mod, VALUE nrec, VALUE recs, VALUE data, VALUE ntype
 {
     char *chk_ntype;
     Check_Type(ntype,T_STRING);
-    Check_SafeStr(ntype);
+    SafeStringValue(ntype);
     chk_ntype = RSTRING_PTR(ntype);
 
     switch (check_numbertype(chk_ntype)){
@@ -1510,7 +1514,7 @@ hdfeos5_ptchkfieldname(VALUE mod,VALUE levelname)
     i_ptid=he5pt->ptid;
 
     Check_Type(levelname,T_STRING);
-    Check_SafeStr(levelname);
+    SafeStringValue(levelname);
     i_levelname = RSTRING_PTR(levelname);
 
     o_level=HE5_PTlevelindx(i_ptid, i_levelname);
@@ -1541,7 +1545,7 @@ hdfeos5_ptsetfield(VALUE mod,VALUE fieldname)
     i_ptid=he5pt->ptid;
 
     Check_Type(fieldname,T_STRING);
-    Check_SafeStr(fieldname);
+    SafeStringValue(fieldname);
     i_fieldname = RSTRING_PTR(fieldname);
 
     o_strbufsize = search_levelsize(i_ptid,i_fieldname);
@@ -1566,7 +1570,7 @@ hdfeos5_ptsetfield_level(VALUE mod,VALUE fieldname,VALUE levelname)
     i_ptid=he5pt->ptid;
 
     Check_Type(fieldname,T_STRING);
-    Check_SafeStr(fieldname);
+    SafeStringValue(fieldname);
     i_fieldname = RSTRING_PTR(fieldname);
     i_levelname = RSTRING_PTR(levelname);
 
