@@ -5,8 +5,18 @@
 #include "narray.h"
 #include<string.h>
 
+/* for compatibility with ruby 1.6 */
+#ifndef RARRAY_PTR
+#define RARRAY_PTR(a) (RARRAY(a)->ptr)
+#endif
+#ifndef RARRAY_LEN
+#define RARRAY_LEN(a) (RARRAY(a)->len)
+#endif
 #ifndef RSTRING_PTR
-#  define RSTRING_PTR(s) (RSTRING(s)->ptr)
+#define RSTRING_PTR(s) (RSTRING(s)->ptr)
+#endif
+#ifndef SafeStringValue
+#define SafeStringValue(s) Check_SafeStr(s)
 #endif
 
 extern int   check_numbertype(char *);
@@ -268,7 +278,7 @@ zanentries_count(hid_t i_zaid, VALUE entrycode)
     long o_count;
 
     Check_Type(entrycode,T_STRING);
-    Check_SafeStr(entrycode);
+    SafeStringValue(entrycode);
     c_entrycode = RSTRING_PTR(entrycode);
 
     o_count = HE5_ZAnentries(i_zaid, change_entrycode(c_entrycode), &o_strbufsize);
@@ -284,7 +294,7 @@ zanentries_strbuf(hid_t i_zaid, VALUE entrycode)
     long o_count;
 
     Check_Type(entrycode,T_STRING);
-    Check_SafeStr(entrycode);
+    SafeStringValue(entrycode);
     c_entrycode = RSTRING_PTR(entrycode);
 
     o_count = HE5_ZAnentries(i_zaid, change_entrycode(c_entrycode), &o_strbufsize);
@@ -309,7 +319,7 @@ hdfeos5_zacreate(VALUE mod, VALUE zaname)
     file=he5file->name;
 
     Check_Type(zaname,T_STRING);
-    Check_SafeStr(zaname);
+    SafeStringValue(zaname);
     i_zaname = RSTRING_PTR(zaname);
 
     zaid = HE5_ZAcreate(i_fid, i_zaname);
@@ -335,7 +345,7 @@ hdfeos5_zaattach(VALUE mod, VALUE zaname)
     i_fname=he5file->name;
 
     Check_Type(zaname,T_STRING);
-    Check_SafeStr(zaname);
+    SafeStringValue(zaname);
     i_zaname = RSTRING_PTR(zaname);
 
     zaid = HE5_ZAattach(i_fid, i_zaname);
@@ -360,7 +370,7 @@ hdfeos5_zadefdim(VALUE mod, VALUE dimname, VALUE dim)
     Data_Get_Struct(mod, struct HE5Za, he5za);
     i_zaid=he5za->zaid;
     Check_Type(dimname,T_STRING);
-    Check_SafeStr(dimname);
+    SafeStringValue(dimname);
     Check_Type(dim,T_FIXNUM);
     i_dimname = RSTRING_PTR(dimname);
     i_dim = NUM2LONG(dim);
@@ -383,7 +393,7 @@ hdfeos5_zadiminfo(VALUE mod, VALUE dimname)
     i_zaid=he5za->zaid;
 
     Check_Type(dimname,T_STRING);
-    Check_SafeStr(dimname);
+    SafeStringValue(dimname);
     i_dimname = RSTRING_PTR(dimname);
 
     o_ndim = HE5_ZAdiminfo(i_zaid, i_dimname);
@@ -494,7 +504,7 @@ hdfeos5_zadefcomp(VALUE mod, VALUE compcode, VALUE compparm)
     i_zaid=he5za->zaid;
 
     Check_Type(compcode,T_STRING);
-    Check_SafeStr(compcode);
+    SafeStringValue(compcode);
     if ((TYPE(compparm) == T_BIGNUM) || (TYPE(compparm) == T_FIXNUM)) {
       compparm = rb_Array(compparm);
     }
@@ -524,7 +534,7 @@ hdfeos5_zadefcomchunk(VALUE mod, VALUE compcode, VALUE compparm, VALUE rank, VAL
     i_zaid=he5za->zaid;
 
     Check_Type(compcode,T_STRING);
-    Check_SafeStr(compcode);
+    SafeStringValue(compcode);
     if ((TYPE(compparm) == T_BIGNUM) || (TYPE(compparm) == T_FIXNUM)) {
       compparm = rb_Array(compparm);
     }
@@ -563,13 +573,13 @@ hdfeos5_zadefine(VALUE file, VALUE fieldname, VALUE dimlist, VALUE maxdimlist, V
     i_zaid=he5za->zaid;
 
     Check_Type(fieldname,T_STRING);
-    Check_SafeStr(fieldname);
+    SafeStringValue(fieldname);
     Check_Type(dimlist,T_STRING);
-    Check_SafeStr(dimlist);
+    SafeStringValue(dimlist);
     Check_Type(maxdimlist,T_STRING);
-    Check_SafeStr(maxdimlist);
+    SafeStringValue(maxdimlist);
     Check_Type(numbertype,T_STRING);
-    Check_SafeStr(numbertype);
+    SafeStringValue(numbertype);
 
     i_fieldname = RSTRING_PTR(fieldname);
     i_dimlist = RSTRING_PTR(dimlist);
@@ -601,7 +611,7 @@ hdfeos5_zawritedatameta(VALUE mod, VALUE dimlist, VALUE mvalue)
     i_zaid=he5field->zaid;
 
     Check_Type(dimlist,T_STRING);
-    Check_SafeStr(dimlist);
+    SafeStringValue(dimlist);
     Check_Type(mvalue,T_FIXNUM);
 
     i_dimlist = RSTRING_PTR(dimlist);
@@ -631,9 +641,9 @@ hdfeos5_zawriteattr(VALUE mod, VALUE attrname, VALUE numbertype, VALUE count, VA
     i_zaid=he5za->zaid;
 
     Check_Type(attrname,T_STRING);
-    Check_SafeStr(attrname);
+    SafeStringValue(attrname);
     Check_Type(numbertype,T_STRING);
-    Check_SafeStr(numbertype);
+    SafeStringValue(numbertype);
     count = rb_Array(count);
 
     i_attrname = RSTRING_PTR(attrname);
@@ -665,7 +675,7 @@ hdfeos5_za_get_att(VALUE mod, VALUE attrname)
     i_zaid=he5za->zaid;
 
     Check_Type(attrname,T_STRING);
-    Check_SafeStr(attrname);
+    SafeStringValue(attrname);
     i_attrname = RSTRING_PTR(attrname);
 
     o_rtn_val = HE5_ZAattrinfo(i_zaid, i_attrname, &o_ntype, &o_count);
@@ -802,11 +812,11 @@ hdfeos5_zainqdatatype(VALUE mod, VALUE fieldname, VALUE attrname, VALUE group)
     i_zaid=he5za->zaid;
 
     Check_Type(fieldname,T_STRING);
-    Check_SafeStr(fieldname);
+    SafeStringValue(fieldname);
     Check_Type(attrname,T_STRING);
-    Check_SafeStr(attrname);
+    SafeStringValue(attrname);
     Check_Type(group,T_STRING);
-    Check_SafeStr(group);
+    SafeStringValue(group);
 
     i_fieldname = RSTRING_PTR(fieldname);
     i_attrname = RSTRING_PTR(attrname);
@@ -838,7 +848,7 @@ hdfeos5_zachunkinfo(VALUE mod, VALUE fldname)
     Data_Get_Struct(mod, struct HE5Za, he5za);
     i_zaid=he5za->zaid;
     Check_Type(fldname,T_STRING);
-    Check_SafeStr(fldname);
+    SafeStringValue(fldname);
     i_fldname = RSTRING_PTR(fldname);
 
     o_rtn_val = HE5_ZAchunkinfo(i_zaid, i_fldname, &o_chunk_rank, NULL);
@@ -869,7 +879,7 @@ hdfeos5_zanentries(VALUE mod, VALUE entrycode)
     i_zaid=he5za->zaid;
 
     Check_Type(entrycode,T_STRING);
-    Check_SafeStr(entrycode);
+    SafeStringValue(entrycode);
     i_entrycode = change_entrycode(RSTRING_PTR(entrycode));
 
     o_count = HE5_ZAnentries(i_zaid, i_entrycode, &o_strbufsize);
@@ -914,7 +924,7 @@ hdfeos5_zawrite(VALUE mod, VALUE start, VALUE stride, VALUE count, VALUE data, V
 {
     char *chk_ntype;
     Check_Type(ntype,T_STRING);
-    Check_SafeStr(ntype);
+    SafeStringValue(ntype);
     chk_ntype = RSTRING_PTR(ntype);
 
     switch (check_numbertype(chk_ntype)){
@@ -965,7 +975,7 @@ hdfeos5_zaread(VALUE mod, VALUE start, VALUE stride, VALUE edge, VALUE ntype)
 {
     char *chk_ntype;
     Check_Type(ntype,T_STRING);
-    Check_SafeStr(ntype);
+    SafeStringValue(ntype);
     chk_ntype = RSTRING_PTR(ntype);
 
     switch (check_numbertype(chk_ntype)){
@@ -1081,9 +1091,9 @@ hdfeos5_zasetfillvalue(VALUE mod, VALUE fieldname,VALUE numbertype, VALUE fillva
     i_zaid=he5za->zaid;
 
     Check_Type(fieldname,T_STRING);
-    Check_SafeStr(fieldname);
+    SafeStringValue(fieldname);
     Check_Type(numbertype,T_STRING);
-    Check_SafeStr(numbertype);
+    SafeStringValue(numbertype);
     i_fieldname = RSTRING_PTR(fieldname);
     i_numbertype = change_numbertype(RSTRING_PTR(numbertype));
 
@@ -1093,7 +1103,7 @@ hdfeos5_zasetfillvalue(VALUE mod, VALUE fieldname,VALUE numbertype, VALUE fillva
     }
     if (TYPE(fillval) == T_STRING) {
       Check_Type(fillval,T_STRING);
-      Check_SafeStr(fillval);
+      SafeStringValue(fillval);
       i_fillval = RSTRING_PTR(fillval);
     }
 
@@ -1119,7 +1129,7 @@ hdfeos5_zagetfillvalue(VALUE mod,VALUE fieldname)
     i_zaid=he5za->zaid;
 
     Check_Type(fieldname,T_STRING);
-    Check_SafeStr(fieldname);
+    SafeStringValue(fieldname);
     i_fieldname = RSTRING_PTR(fieldname);
 
     o_fillval = (void*)malloc(HE5_BLKSIZE);
@@ -1148,9 +1158,9 @@ hdfeos5_zawritegrpattr(VALUE mod, VALUE attrname, VALUE numbertype, VALUE count,
     i_zaid=he5za->zaid;
 
     Check_Type(attrname,T_STRING);
-    Check_SafeStr(attrname);
+    SafeStringValue(attrname);
     Check_Type(numbertype,T_STRING);
-    Check_SafeStr(numbertype);
+    SafeStringValue(numbertype);
     count = rb_Array(count);
 
     i_attrname = RSTRING_PTR(attrname);
@@ -1182,7 +1192,7 @@ hdfeos5_za_get_grpatt(VALUE mod, VALUE attrname)
     i_zaid=he5za->zaid;
 
     Check_Type(attrname,T_STRING);
-    Check_SafeStr(attrname);
+    SafeStringValue(attrname);
     i_attrname = RSTRING_PTR(attrname);
 
     o_rtn_val = HE5_ZAgrpattrinfo(i_zaid, i_attrname, &o_ntype, &o_count);
@@ -1241,9 +1251,9 @@ hdfeos5_zawritelocattr(VALUE mod, VALUE attrname, VALUE numbertype, VALUE count,
     i_zaid=he5field->zaid;
 
     Check_Type(attrname,T_STRING);
-    Check_SafeStr(attrname);
+    SafeStringValue(attrname);
     Check_Type(numbertype,T_STRING);
-    Check_SafeStr(numbertype);
+    SafeStringValue(numbertype);
     count = rb_Array(count);
 
     i_attrname = RSTRING_PTR(attrname);
@@ -1277,7 +1287,7 @@ hdfeos5_zafield_get_att(VALUE mod,VALUE  attrname)
     i_fieldname=he5field->name;
     i_zaid=he5field->zaid;
     Check_Type(attrname,T_STRING);
-    Check_SafeStr(attrname);
+    SafeStringValue(attrname);
     i_attrname = RSTRING_PTR(attrname);
 
     o_rtn_val = HE5_ZAlocattrinfo(i_zaid, i_fieldname, i_attrname, 
@@ -1337,7 +1347,7 @@ hdfeos5_zasetalias(VALUE mod, VALUE fieldname)
     i_zaid=he5za->zaid;
 
     Check_Type(fieldname,T_STRING);
-    Check_SafeStr(fieldname);
+    SafeStringValue(fieldname);
     i_fieldname = RSTRING_PTR(fieldname);
 
     o_rtn_val = HE5_ZAsetalias(i_zaid, i_fieldname, o_aliaslist);
@@ -1361,9 +1371,9 @@ hdfeos5_zadropalias(VALUE mod, VALUE fldgroup, VALUE aliasname)
     i_zaid=he5za->zaid;
 
     Check_Type(fldgroup,T_STRING);
-    Check_SafeStr(fldgroup);
+    SafeStringValue(fldgroup);
     Check_Type(aliasname,T_STRING);
-    Check_SafeStr(aliasname);
+    SafeStringValue(aliasname);
 
     i_fldgroup = change_groupcode(RSTRING_PTR(fldgroup));
     i_aliasname = RSTRING_PTR(aliasname);
@@ -1416,9 +1426,9 @@ hdfeos5_zaaliasinfo(VALUE mod, VALUE fldgroup, VALUE aliasname)
     i_zaid=he5za->zaid;
 
     Check_Type(fldgroup,T_STRING);
-    Check_SafeStr(fldgroup);
+    SafeStringValue(fldgroup);
     Check_Type(aliasname,T_STRING);
-    Check_SafeStr(aliasname);
+    SafeStringValue(aliasname);
 
     i_fldgroup = change_groupcode(RSTRING_PTR(fldgroup));
     i_aliasname = RSTRING_PTR(aliasname);
@@ -1449,7 +1459,7 @@ hdfeos5_zagetaliaslist(VALUE mod, VALUE fldgroup)
     i_zaid=he5za->zaid;
 
     Check_Type(fldgroup,T_STRING);
-    Check_SafeStr(fldgroup);
+    SafeStringValue(fldgroup);
     i_fldgroup = change_groupcode(RSTRING_PTR(fldgroup));
 
     o_rtn_val = HE5_ZAgetaliaslist(i_zaid, i_fldgroup, o_aliaslist, &o_strbufsize);
@@ -1474,10 +1484,10 @@ hdfeos5_zafldrename(VALUE mod, VALUE oldfieldname,VALUE newfieldname)
     i_zaid=he5za->zaid;
 
     Check_Type(oldfieldname,T_STRING);
-    Check_SafeStr(oldfieldname);
+    SafeStringValue(oldfieldname);
     i_oldfieldname = RSTRING_PTR(oldfieldname);
     Check_Type(newfieldname,T_STRING);
-    Check_SafeStr(newfieldname);
+    SafeStringValue(newfieldname);
     i_newfieldname = RSTRING_PTR(newfieldname);
 
 
@@ -1502,9 +1512,9 @@ hdfeos5_zamountexternal(VALUE mod, VALUE fldgroup, VALUE extfilename)
     i_zaid=he5za->zaid;
 
     Check_Type(fldgroup,T_STRING);
-    Check_SafeStr(fldgroup);
+    SafeStringValue(fldgroup);
     Check_Type(extfilename,T_STRING);
-    Check_SafeStr(extfilename);
+    SafeStringValue(extfilename);
 
     i_fldgroup = change_groupcode(RSTRING_PTR(fldgroup));
     i_extfilename = RSTRING_PTR(extfilename);
@@ -1529,7 +1539,7 @@ hdfeos5_zaunmount(VALUE mod, VALUE fldgroup, VALUE fileid)
     i_zaid=he5za->zaid;
 
     Check_Type(fldgroup,T_STRING);
-    Check_SafeStr(fldgroup);
+    SafeStringValue(fldgroup);
     Check_Type(fileid,T_FIXNUM);
 
     i_fldgroup = change_groupcode(RSTRING_PTR(fldgroup));
@@ -1556,9 +1566,9 @@ hdfeos5_zareadexternal(VALUE mod, VALUE fldgroup, VALUE fieldname)
     i_zaid=he5za->zaid;
 
     Check_Type(fldgroup,T_STRING);
-    Check_SafeStr(fldgroup);
+    SafeStringValue(fldgroup);
     Check_Type(fieldname,T_STRING);
-    Check_SafeStr(fieldname);
+    SafeStringValue(fieldname);
     i_fldgroup = change_groupcode(RSTRING_PTR(fldgroup));
     i_fieldname = RSTRING_PTR(fieldname);
 
@@ -1585,7 +1595,7 @@ hdfeos5_zasetextdata(VALUE mod, VALUE filelist, VALUE offset, VALUE size)
     i_zaid=he5za->zaid;
 
     Check_Type(filelist,T_STRING);
-    Check_SafeStr(filelist);
+    SafeStringValue(filelist);
     if ((TYPE(offset) == T_BIGNUM) || (TYPE(offset) == T_FIXNUM)) {
       offset = rb_Array(offset);
     }
@@ -1625,7 +1635,7 @@ hdfeos5_zagetextdata(VALUE mod, VALUE fieldname)
     i_zaid=he5za->zaid;
 
     Check_Type(fieldname,T_STRING);
-    Check_SafeStr(fieldname);
+    SafeStringValue(fieldname);
 
     i_fieldname = RSTRING_PTR(fieldname);
 
@@ -1694,7 +1704,7 @@ hdfeos5_zasetfield(VALUE mod,VALUE fieldname)
     i_zaid=he5za->zaid;
 
     Check_Type(fieldname,T_STRING);
-    Check_SafeStr(fieldname);
+    SafeStringValue(fieldname);
     i_fieldname = RSTRING_PTR(fieldname);
     
     he5field = HE5ZaField_init(i_fieldname, i_zaid, mod);
@@ -1826,12 +1836,12 @@ hdfeos5_zawrite_char(VALUE mod, VALUE start, VALUE stride, VALUE count, VALUE da
     status = HE5_ZAinfo(i_zaid, i_fldname, &i_rank, hs_dims, &i_ntype, o_dimlist, NULL);
 
     Check_Type(start,T_ARRAY);
-    if(RARRAY(start)->len < i_rank) {
+    if(RARRAY_LEN(start) < i_rank) {
       rb_raise(rb_eHE5Error, "Length of 'start' is too short [%s:%d]",__FILE__,__LINE__);
     }
     c_start=ALLOCA_N(signed long long,i_rank);
     for(i=0; i<i_rank; i++){
-      l_start=NUM2INT(RARRAY(start)->ptr[i]);    
+      l_start=NUM2INT(RARRAY_PTR(start)[i]);    
       if(l_start < 0) {
 	l_start += hs_dims[i];
       }
@@ -1846,11 +1856,11 @@ hdfeos5_zawrite_char(VALUE mod, VALUE start, VALUE stride, VALUE count, VALUE da
       break;
     default:
       Check_Type(stride,T_ARRAY);
-      if(RARRAY(stride)->len < i_rank) {
+      if(RARRAY_LEN(stride) < i_rank) {
 	  rb_raise(rb_eHE5Error, "Length of 'stride' is too short [%s:%d]",__FILE__,__LINE__);
       }
       for(i=0; i<i_rank; i++){
-	c_stride[i]=NUM2INT(RARRAY(stride)->ptr[i]);
+	c_stride[i]=NUM2INT(RARRAY_PTR(stride)[i]);
 	if(c_stride[i]==0) {
 	  rb_raise(rb_eHE5Error, "stride cannot be zero [%s:%d]",__FILE__,__LINE__);
 	}
@@ -1868,11 +1878,11 @@ hdfeos5_zawrite_char(VALUE mod, VALUE start, VALUE stride, VALUE count, VALUE da
       break;
     default:
       Check_Type(count,T_ARRAY);
-      if(RARRAY(count)->len <i_rank) {
+      if(RARRAY_LEN(count) < i_rank) {
         rb_raise(rb_eHE5Error, "Length of 'end' is too short [%s:%d]",__FILE__,__LINE__);
       }
       for(i=0; i<i_rank; i++){
-        l_count= NUM2INT(RARRAY(count)->ptr[i]);
+        l_count= NUM2INT(RARRAY_PTR(count)[i]);
         if(l_count < 0) {
 	  l_count +=hs_dims[i];
         }
@@ -1922,12 +1932,12 @@ hdfeos5_zawrite_short(VALUE mod, VALUE start, VALUE stride, VALUE count, VALUE d
     status = HE5_ZAinfo(i_zaid, i_fldname, &i_rank, hs_dims, &i_ntype, o_dimlist, NULL);
 
     Check_Type(start,T_ARRAY);
-    if(RARRAY(start)->len < i_rank) {
+    if(RARRAY_LEN(start) < i_rank) {
       rb_raise(rb_eHE5Error, "Length of 'start' is too short [%s:%d]",__FILE__,__LINE__);
     }
     c_start=ALLOCA_N(signed long long,i_rank);
     for(i=0; i<i_rank; i++){
-      l_start=NUM2INT(RARRAY(start)->ptr[i]);    
+      l_start=NUM2INT(RARRAY_PTR(start)[i]);    
       if(l_start < 0) {
 	l_start += hs_dims[i];
       }
@@ -1942,11 +1952,11 @@ hdfeos5_zawrite_short(VALUE mod, VALUE start, VALUE stride, VALUE count, VALUE d
       break;
     default:
       Check_Type(stride,T_ARRAY);
-      if(RARRAY(stride)->len < i_rank) {
+      if(RARRAY_LEN(stride) < i_rank) {
 	  rb_raise(rb_eHE5Error, "Length of 'stride' is too short [%s:%d]",__FILE__,__LINE__);
       }
       for(i=0; i<i_rank; i++){
-	c_stride[i]=NUM2INT(RARRAY(stride)->ptr[i]);
+	c_stride[i]=NUM2INT(RARRAY_PTR(stride)[i]);
 	if(c_stride[i]==0) {
 	  rb_raise(rb_eHE5Error, "stride cannot be zero [%s:%d]",__FILE__,__LINE__);
 	}
@@ -1964,11 +1974,11 @@ hdfeos5_zawrite_short(VALUE mod, VALUE start, VALUE stride, VALUE count, VALUE d
       break;
     default:
       Check_Type(count,T_ARRAY);
-      if(RARRAY(count)->len <i_rank) {
+      if(RARRAY_LEN(count) < i_rank) {
         rb_raise(rb_eHE5Error, "Length of 'end' is too short [%s:%d]",__FILE__,__LINE__);
       }
       for(i=0; i<i_rank; i++){
-        l_count= NUM2INT(RARRAY(count)->ptr[i]);
+        l_count= NUM2INT(RARRAY_PTR(count)[i]);
         if(l_count < 0) {
 	  l_count +=hs_dims[i];
         }
@@ -2018,12 +2028,12 @@ hdfeos5_zawrite_int(VALUE mod, VALUE start, VALUE stride, VALUE count, VALUE dat
     status = HE5_ZAinfo(i_zaid, i_fldname, &i_rank, hs_dims, &i_ntype, o_dimlist, NULL);
 
     Check_Type(start,T_ARRAY);
-    if(RARRAY(start)->len < i_rank) {
+    if(RARRAY_LEN(start) < i_rank) {
       rb_raise(rb_eHE5Error, "Length of 'start' is too short [%s:%d]",__FILE__,__LINE__);
     }
     c_start=ALLOCA_N(signed long long,i_rank);
     for(i=0; i<i_rank; i++){
-      l_start=NUM2INT(RARRAY(start)->ptr[i]);    
+      l_start=NUM2INT(RARRAY_PTR(start)[i]);    
       if(l_start < 0) {
 	l_start += hs_dims[i];
       }
@@ -2038,11 +2048,11 @@ hdfeos5_zawrite_int(VALUE mod, VALUE start, VALUE stride, VALUE count, VALUE dat
       break;
     default:
       Check_Type(stride,T_ARRAY);
-      if(RARRAY(stride)->len < i_rank) {
+      if(RARRAY_LEN(stride) < i_rank) {
 	  rb_raise(rb_eHE5Error, "Length of 'stride' is too short [%s:%d]",__FILE__,__LINE__);
       }
       for(i=0; i<i_rank; i++){
-	c_stride[i]=NUM2INT(RARRAY(stride)->ptr[i]);
+	c_stride[i]=NUM2INT(RARRAY_PTR(stride)[i]);
 	if(c_stride[i]==0) {
 	  rb_raise(rb_eHE5Error, "stride cannot be zero [%s:%d]",__FILE__,__LINE__);
 	}
@@ -2060,11 +2070,11 @@ hdfeos5_zawrite_int(VALUE mod, VALUE start, VALUE stride, VALUE count, VALUE dat
       break;
     default:
       Check_Type(count,T_ARRAY);
-      if(RARRAY(count)->len <i_rank) {
+      if(RARRAY_LEN(count) < i_rank) {
         rb_raise(rb_eHE5Error, "Length of 'end' is too short [%s:%d]",__FILE__,__LINE__);
       }
       for(i=0; i<i_rank; i++){
-        l_count= NUM2INT(RARRAY(count)->ptr[i]);
+        l_count= NUM2INT(RARRAY_PTR(count)[i]);
         if(l_count < 0) {
 	  l_count +=hs_dims[i];
         }
@@ -2114,12 +2124,12 @@ hdfeos5_zawrite_long(VALUE mod, VALUE start, VALUE stride, VALUE count, VALUE da
     status = HE5_ZAinfo(i_zaid, i_fldname, &i_rank, hs_dims, &i_ntype, o_dimlist, NULL);
 
     Check_Type(start,T_ARRAY);
-    if(RARRAY(start)->len < i_rank) {
+    if(RARRAY_LEN(start) < i_rank) {
       rb_raise(rb_eHE5Error, "Length of 'start' is too short [%s:%d]",__FILE__,__LINE__);
     }
     c_start=ALLOCA_N(signed long long,i_rank);
     for(i=0; i<i_rank; i++){
-      l_start=NUM2INT(RARRAY(start)->ptr[i]);
+      l_start=NUM2INT(RARRAY_PTR(start)[i]);
       if(l_start < 0) {
 	l_start += hs_dims[i];
       }
@@ -2134,11 +2144,11 @@ hdfeos5_zawrite_long(VALUE mod, VALUE start, VALUE stride, VALUE count, VALUE da
       break;
     default:
       Check_Type(stride,T_ARRAY);
-      if(RARRAY(stride)->len < i_rank) {
+      if(RARRAY_LEN(stride) < i_rank) {
 	  rb_raise(rb_eHE5Error, "Length of 'stride' is too short [%s:%d]",__FILE__,__LINE__);
       }
       for(i=0; i<i_rank; i++){
-	c_stride[i]=NUM2INT(RARRAY(stride)->ptr[i]);
+	c_stride[i]=NUM2INT(RARRAY_PTR(stride)[i]);
 	if(c_stride[i]==0) {
 	  rb_raise(rb_eHE5Error, "stride cannot be zero [%s:%d]",__FILE__,__LINE__);
 	}
@@ -2156,11 +2166,11 @@ hdfeos5_zawrite_long(VALUE mod, VALUE start, VALUE stride, VALUE count, VALUE da
       break;
     default:
       Check_Type(count,T_ARRAY);
-      if(RARRAY(count)->len <i_rank) {
+      if(RARRAY_LEN(count) < i_rank) {
         rb_raise(rb_eHE5Error, "Length of 'end' is too short [%s:%d]",__FILE__,__LINE__);
       }
       for(i=0; i<i_rank; i++){
-        l_count= NUM2INT(RARRAY(count)->ptr[i]);
+        l_count= NUM2INT(RARRAY_PTR(count)[i]);
         if(l_count < 0) {
 	  l_count +=hs_dims[i];
         }
@@ -2210,12 +2220,12 @@ hdfeos5_zawrite_float(VALUE mod, VALUE start, VALUE stride, VALUE count, VALUE d
     status = HE5_ZAinfo(i_zaid, i_fldname, &i_rank, hs_dims, &i_ntype, o_dimlist, NULL);
 
     Check_Type(start,T_ARRAY);
-    if(RARRAY(start)->len < i_rank) {
+    if(RARRAY_LEN(start) < i_rank) {
       rb_raise(rb_eHE5Error, "Length of 'start' is too short [%s:%d]",__FILE__,__LINE__);
     }
     c_start=ALLOCA_N(signed long long,i_rank);
     for(i=0; i<i_rank; i++){
-      l_start=NUM2INT(RARRAY(start)->ptr[i]);    
+      l_start=NUM2INT(RARRAY_PTR(start)[i]);    
       if(l_start < 0) {
 	l_start += hs_dims[i];
       }
@@ -2230,11 +2240,11 @@ hdfeos5_zawrite_float(VALUE mod, VALUE start, VALUE stride, VALUE count, VALUE d
       break;
     default:
       Check_Type(stride,T_ARRAY);
-      if(RARRAY(stride)->len < i_rank) {
+      if(RARRAY_LEN(stride) < i_rank) {
 	  rb_raise(rb_eHE5Error, "Length of 'stride' is too short [%s:%d]",__FILE__,__LINE__);
       }
       for(i=0; i<i_rank; i++){
-	c_stride[i]=NUM2INT(RARRAY(stride)->ptr[i]);
+	c_stride[i]=NUM2INT(RARRAY_PTR(stride)[i]);
 	if(c_stride[i]==0) {
 	  rb_raise(rb_eHE5Error, "stride cannot be zero [%s:%d]",__FILE__,__LINE__);
 	}
@@ -2252,11 +2262,11 @@ hdfeos5_zawrite_float(VALUE mod, VALUE start, VALUE stride, VALUE count, VALUE d
       break;
     default:
       Check_Type(count,T_ARRAY);
-      if(RARRAY(count)->len <i_rank) {
+      if(RARRAY_LEN(count) < i_rank) {
         rb_raise(rb_eHE5Error, "Length of 'end' is too short [%s:%d]",__FILE__,__LINE__);
       }
       for(i=0; i<i_rank; i++){
-        l_count= NUM2INT(RARRAY(count)->ptr[i]);
+        l_count= NUM2INT(RARRAY_PTR(count)[i]);
         if(l_count < 0) {
 	  l_count +=hs_dims[i];
         }
@@ -2306,12 +2316,12 @@ hdfeos5_zawrite_double(VALUE mod, VALUE start, VALUE stride, VALUE count, VALUE
     status = HE5_ZAinfo(i_zaid, i_fldname, &i_rank, hs_dims, &i_ntype, o_dimlist, NULL);
 
     Check_Type(start,T_ARRAY);
-    if(RARRAY(start)->len < i_rank) {
+    if(RARRAY_LEN(start) < i_rank) {
       rb_raise(rb_eHE5Error, "Length of 'start' is too short [%s:%d]",__FILE__,__LINE__);
     }
     c_start=ALLOCA_N(signed long long,i_rank);
     for(i=0; i<i_rank; i++){
-      l_start=NUM2INT(RARRAY(start)->ptr[i]);    
+      l_start=NUM2INT(RARRAY_PTR(start)[i]);    
       if(l_start < 0) {
 	l_start += hs_dims[i];
       }
@@ -2326,11 +2336,11 @@ hdfeos5_zawrite_double(VALUE mod, VALUE start, VALUE stride, VALUE count, VALUE
       break;
     default:
       Check_Type(stride,T_ARRAY);
-      if(RARRAY(stride)->len < i_rank) {
+      if(RARRAY_LEN(stride) < i_rank) {
 	  rb_raise(rb_eHE5Error, "Length of 'stride' is too short [%s:%d]",__FILE__,__LINE__);
       }
       for(i=0; i<i_rank; i++){
-	c_stride[i]=NUM2INT(RARRAY(stride)->ptr[i]);
+	c_stride[i]=NUM2INT(RARRAY_PTR(stride)[i]);
 	if(c_stride[i]==0) {
 	  rb_raise(rb_eHE5Error, "stride cannot be zero [%s:%d]",__FILE__,__LINE__);
 	}
@@ -2348,11 +2358,11 @@ hdfeos5_zawrite_double(VALUE mod, VALUE start, VALUE stride, VALUE count, VALUE
       break;
     default:
       Check_Type(count,T_ARRAY);
-      if(RARRAY(count)->len <i_rank) {
+      if(RARRAY_LEN(count) < i_rank) {
         rb_raise(rb_eHE5Error, "Length of 'end' is too short [%s:%d]",__FILE__,__LINE__);
       }
       for(i=0; i<i_rank; i++){
-        l_count= NUM2INT(RARRAY(count)->ptr[i]);
+        l_count= NUM2INT(RARRAY_PTR(count)[i]);
         if(l_count < 0) {
 	  l_count +=hs_dims[i];
         }
@@ -2401,13 +2411,13 @@ hdfeos5_zaread_char(VALUE mod, VALUE start, VALUE stride, VALUE count)
     status = HE5_ZAinfo(i_zaid, i_fldname, &i_rank, hs_dims, &i_ntype, NULL, NULL);
 
     Check_Type(start,T_ARRAY);
-    if(RARRAY(start)->len < i_rank) {
+    if(RARRAY_LEN(start) < i_rank) {
       rb_raise(rb_eHE5Error, "Length of 'start' is too short [%s:%d]",
 	       __FILE__,__LINE__);
     }
     c_start=ALLOCA_N(signed long long,i_rank);
     for(i=0; i<i_rank; i++){
-      l_start=NUM2INT(RARRAY(start)->ptr[i_rank-1-i]);
+      l_start=NUM2INT(RARRAY_PTR(start)[i_rank-1-i]);
       if(l_start < 0) {
 	l_start += hs_dims[i];
       }
@@ -2432,12 +2442,12 @@ hdfeos5_zaread_char(VALUE mod, VALUE start, VALUE stride, VALUE count)
       break;
     default:
       Check_Type(stride,T_ARRAY);
-      if(RARRAY(stride)->len < i_rank) {
+      if(RARRAY_LEN(stride) < i_rank) {
 	  rb_raise(rb_eHE5Error, "Length of 'stride' is too short [%s:%d]",
 		   __FILE__,__LINE__);
       }
       for(i=0; i<i_rank; i++){
-	c_stride[i]=NUM2INT(RARRAY(stride)->ptr[i_rank-1-i]);
+	c_stride[i]=NUM2INT(RARRAY_PTR(stride)[i_rank-1-i]);
 	if(c_stride[i]==0) {
 	  rb_raise(rb_eHE5Error, "stride cannot be zero [%s:%d]",__FILE__,__LINE__);
 	}
@@ -2462,11 +2472,11 @@ hdfeos5_zaread_char(VALUE mod, VALUE start, VALUE stride, VALUE count)
       break;
     default:
       Check_Type(count,T_ARRAY);
-      if(RARRAY(count)->len <i_rank) {
+      if(RARRAY_LEN(count) < i_rank) {
         rb_raise(rb_eHE5Error, "Length of 'end' is too short [%s:%d]",__FILE__,__LINE__);
       }
       for(i=0; i<i_rank; i++){
-        l_count= NUM2INT(RARRAY(count)->ptr[i_rank-1-i]);
+        l_count= NUM2INT(RARRAY_PTR(count)[i_rank-1-i]);
         if(l_count < 0) {
 	  l_count +=hs_dims[i];
         }
@@ -2515,13 +2525,13 @@ hdfeos5_zaread_short(VALUE mod, VALUE start, VALUE stride, VALUE count)
     status = HE5_ZAinfo(i_zaid, i_fldname, &i_rank, hs_dims, &i_ntype, NULL, NULL);
 
     Check_Type(start,T_ARRAY);
-    if(RARRAY(start)->len < i_rank) {
+    if(RARRAY_LEN(start) < i_rank) {
       rb_raise(rb_eHE5Error, "Length of 'start' is too short [%s:%d]",
 	       __FILE__,__LINE__);
     }
     c_start=ALLOCA_N(signed long long,i_rank);
     for(i=0; i<i_rank; i++){
-      l_start=NUM2INT(RARRAY(start)->ptr[i_rank-1-i]);
+      l_start=NUM2INT(RARRAY_PTR(start)[i_rank-1-i]);
       if(l_start < 0) {
 	l_start += hs_dims[i];
       }
@@ -2546,12 +2556,12 @@ hdfeos5_zaread_short(VALUE mod, VALUE start, VALUE stride, VALUE count)
       break;
     default:
       Check_Type(stride,T_ARRAY);
-      if(RARRAY(stride)->len < i_rank) {
+      if(RARRAY_LEN(stride) < i_rank) {
 	  rb_raise(rb_eHE5Error, "Length of 'stride' is too short [%s:%d]",
 		   __FILE__,__LINE__);
       }
       for(i=0; i<i_rank; i++){
-	c_stride[i]=NUM2INT(RARRAY(stride)->ptr[i_rank-1-i]);
+	c_stride[i]=NUM2INT(RARRAY_PTR(stride)[i_rank-1-i]);
 	if(c_stride[i]==0) {
 	  rb_raise(rb_eHE5Error, "stride cannot be zero [%s:%d]",__FILE__,__LINE__);
 	}
@@ -2576,11 +2586,11 @@ hdfeos5_zaread_short(VALUE mod, VALUE start, VALUE stride, VALUE count)
       break;
     default:
       Check_Type(count,T_ARRAY);
-      if(RARRAY(count)->len <i_rank) {
+      if(RARRAY_LEN(count) < i_rank) {
         rb_raise(rb_eHE5Error, "Length of 'end' is too short [%s:%d]",__FILE__,__LINE__);
       }
       for(i=0; i<i_rank; i++){
-        l_count= NUM2INT(RARRAY(count)->ptr[i_rank-1-i]);
+        l_count= NUM2INT(RARRAY_PTR(count)[i_rank-1-i]);
         if(l_count < 0) {
 	  l_count +=hs_dims[i];
         }
@@ -2629,13 +2639,13 @@ hdfeos5_zaread_int(VALUE mod, VALUE start, VALUE stride, VALUE count)
     status = HE5_ZAinfo(i_zaid, i_fldname, &i_rank, hs_dims, &i_ntype, NULL, NULL);
 
     Check_Type(start,T_ARRAY);
-    if(RARRAY(start)->len < i_rank) {
+    if(RARRAY_LEN(start) < i_rank) {
       rb_raise(rb_eHE5Error, "Length of 'start' is too short [%s:%d]",
 	       __FILE__,__LINE__);
     }
     c_start=ALLOCA_N(signed long long,i_rank);
     for(i=0; i<i_rank; i++){
-      l_start=NUM2INT(RARRAY(start)->ptr[i_rank-1-i]);
+      l_start=NUM2INT(RARRAY_PTR(start)[i_rank-1-i]);
       if(l_start < 0) {
 	l_start += hs_dims[i];
       }
@@ -2660,12 +2670,12 @@ hdfeos5_zaread_int(VALUE mod, VALUE start, VALUE stride, VALUE count)
       break;
     default:
       Check_Type(stride,T_ARRAY);
-      if(RARRAY(stride)->len < i_rank) {
+      if(RARRAY_LEN(stride) < i_rank) {
 	  rb_raise(rb_eHE5Error, "Length of 'stride' is too short [%s:%d]",
 		   __FILE__,__LINE__);
       }
       for(i=0; i<i_rank; i++){
-	c_stride[i]=NUM2INT(RARRAY(stride)->ptr[i_rank-1-i]);
+	c_stride[i]=NUM2INT(RARRAY_PTR(stride)[i_rank-1-i]);
 	if(c_stride[i]==0) {
 	  rb_raise(rb_eHE5Error, "stride cannot be zero [%s:%d]",__FILE__,__LINE__);
 	}
@@ -2690,11 +2700,11 @@ hdfeos5_zaread_int(VALUE mod, VALUE start, VALUE stride, VALUE count)
       break;
     default:
       Check_Type(count,T_ARRAY);
-      if(RARRAY(count)->len <i_rank) {
+      if(RARRAY_LEN(count) < i_rank) {
         rb_raise(rb_eHE5Error, "Length of 'end' is too short [%s:%d]",__FILE__,__LINE__);
       }
       for(i=0; i<i_rank; i++){
-        l_count= NUM2INT(RARRAY(count)->ptr[i_rank-1-i]);
+        l_count= NUM2INT(RARRAY_PTR(count)[i_rank-1-i]);
         if(l_count < 0) {
 	  l_count +=hs_dims[i];
         }
@@ -2743,13 +2753,13 @@ hdfeos5_zaread_long(VALUE mod, VALUE start, VALUE stride, VALUE count)
     status = HE5_ZAinfo(i_zaid, i_fldname, &i_rank, hs_dims, &i_ntype, NULL, NULL);
 
     Check_Type(start,T_ARRAY);
-    if(RARRAY(start)->len < i_rank) {
+    if(RARRAY_LEN(start) < i_rank) {
       rb_raise(rb_eHE5Error, "Length of 'start' is too short [%s:%d]",
 	       __FILE__,__LINE__);
     }
     c_start=ALLOCA_N(signed long long,i_rank);
     for(i=0; i<i_rank; i++){
-      l_start=NUM2INT(RARRAY(start)->ptr[i_rank-1-i]);
+      l_start=NUM2INT(RARRAY_PTR(start)[i_rank-1-i]);
       if(l_start < 0) {
 	l_start += hs_dims[i];
       }
@@ -2774,12 +2784,12 @@ hdfeos5_zaread_long(VALUE mod, VALUE start, VALUE stride, VALUE count)
       break;
     default:
       Check_Type(stride,T_ARRAY);
-      if(RARRAY(stride)->len < i_rank) {
+      if(RARRAY_LEN(stride) < i_rank) {
 	  rb_raise(rb_eHE5Error, "Length of 'stride' is too short [%s:%d]",
 		   __FILE__,__LINE__);
       }
       for(i=0; i<i_rank; i++){
-	c_stride[i]=NUM2INT(RARRAY(stride)->ptr[i_rank-1-i]);
+	c_stride[i]=NUM2INT(RARRAY_PTR(stride)[i_rank-1-i]);
 	if(c_stride[i]==0) {
 	  rb_raise(rb_eHE5Error, "stride cannot be zero [%s:%d]",__FILE__,__LINE__);
 	}
@@ -2804,11 +2814,11 @@ hdfeos5_zaread_long(VALUE mod, VALUE start, VALUE stride, VALUE count)
       break;
     default:
       Check_Type(count,T_ARRAY);
-      if(RARRAY(count)->len <i_rank) {
+      if(RARRAY_LEN(count) < i_rank) {
         rb_raise(rb_eHE5Error, "Length of 'end' is too short [%s:%d]",__FILE__,__LINE__);
       }
       for(i=0; i<i_rank; i++){
-        l_count= NUM2INT(RARRAY(count)->ptr[i_rank-1-i]);
+        l_count= NUM2INT(RARRAY_PTR(count)[i_rank-1-i]);
         if(l_count < 0) {
 	  l_count +=hs_dims[i];
         }
@@ -2857,13 +2867,13 @@ hdfeos5_zaread_float(VALUE mod, VALUE start, VALUE stride, VALUE count)
     status = HE5_ZAinfo(i_zaid, i_fldname, &i_rank, hs_dims, &i_ntype, NULL, NULL);
 
     Check_Type(start,T_ARRAY);
-    if(RARRAY(start)->len < i_rank) {
+    if(RARRAY_LEN(start) < i_rank) {
       rb_raise(rb_eHE5Error, "Length of 'start' is too short [%s:%d]",
 	       __FILE__,__LINE__);
     }
     c_start=ALLOCA_N(signed long long,i_rank);
     for(i=0; i<i_rank; i++){
-      l_start=NUM2INT(RARRAY(start)->ptr[i_rank-1-i]);
+      l_start=NUM2INT(RARRAY_PTR(start)[i_rank-1-i]);
       if(l_start < 0) {
 	l_start += hs_dims[i];
       }
@@ -2888,12 +2898,12 @@ hdfeos5_zaread_float(VALUE mod, VALUE start, VALUE stride, VALUE count)
       break;
     default:
       Check_Type(stride,T_ARRAY);
-      if(RARRAY(stride)->len < i_rank) {
+      if(RARRAY_LEN(stride) < i_rank) {
 	  rb_raise(rb_eHE5Error, "Length of 'stride' is too short [%s:%d]",
 		   __FILE__,__LINE__);
       }
       for(i=0; i<i_rank; i++){
-	c_stride[i]=NUM2INT(RARRAY(stride)->ptr[i_rank-1-i]);
+	c_stride[i]=NUM2INT(RARRAY_PTR(stride)[i_rank-1-i]);
 	if(c_stride[i]==0) {
 	  rb_raise(rb_eHE5Error, "stride cannot be zero [%s:%d]",__FILE__,__LINE__);
 	}
@@ -2918,11 +2928,11 @@ hdfeos5_zaread_float(VALUE mod, VALUE start, VALUE stride, VALUE count)
       break;
     default:
       Check_Type(count,T_ARRAY);
-      if(RARRAY(count)->len <i_rank) {
+      if(RARRAY_LEN(count) < i_rank) {
         rb_raise(rb_eHE5Error, "Length of 'end' is too short [%s:%d]",__FILE__,__LINE__);
       }
       for(i=0; i<i_rank; i++){
-        l_count= NUM2INT(RARRAY(count)->ptr[i_rank-1-i]);
+        l_count= NUM2INT(RARRAY_PTR(count)[i_rank-1-i]);
         if(l_count < 0) {
 	  l_count +=hs_dims[i];
         }
@@ -2971,13 +2981,13 @@ hdfeos5_zaread_double(VALUE mod, VALUE start, VALUE stride, VALUE count)
     status = HE5_ZAinfo(i_zaid, i_fldname, &i_rank, hs_dims, &i_ntype, NULL, NULL);
 
     Check_Type(start,T_ARRAY);
-    if(RARRAY(start)->len < i_rank) {
+    if(RARRAY_LEN(start) < i_rank) {
       rb_raise(rb_eHE5Error, "Length of 'start' is too short [%s:%d]",
 	       __FILE__,__LINE__);
     }
     c_start=ALLOCA_N(signed long long,i_rank);
     for(i=0; i<i_rank; i++){
-      l_start=NUM2INT(RARRAY(start)->ptr[i_rank-1-i]);
+      l_start=NUM2INT(RARRAY_PTR(start)[i_rank-1-i]);
       if(l_start < 0) {
 	l_start += hs_dims[i];
       }
@@ -3002,12 +3012,12 @@ hdfeos5_zaread_double(VALUE mod, VALUE start, VALUE stride, VALUE count)
       break;
     default:
       Check_Type(stride,T_ARRAY);
-      if(RARRAY(stride)->len < i_rank) {
+      if(RARRAY_LEN(stride) < i_rank) {
 	  rb_raise(rb_eHE5Error, "Length of 'stride' is too short [%s:%d]",
 		   __FILE__,__LINE__);
       }
       for(i=0; i<i_rank; i++){
-	c_stride[i]=NUM2INT(RARRAY(stride)->ptr[i_rank-1-i]);
+	c_stride[i]=NUM2INT(RARRAY_PTR(stride)[i_rank-1-i]);
 	if(c_stride[i]==0) {
 	  rb_raise(rb_eHE5Error, "stride cannot be zero [%s:%d]",__FILE__,__LINE__);
 	}
@@ -3032,11 +3042,11 @@ hdfeos5_zaread_double(VALUE mod, VALUE start, VALUE stride, VALUE count)
       break;
     default:
       Check_Type(count,T_ARRAY);
-      if(RARRAY(count)->len <i_rank) {
+      if(RARRAY_LEN(count) < i_rank) {
         rb_raise(rb_eHE5Error, "Length of 'end' is too short [%s:%d]",__FILE__,__LINE__);
       }
       for(i=0; i<i_rank; i++){
-        l_count= NUM2INT(RARRAY(count)->ptr[i_rank-1-i]);
+        l_count= NUM2INT(RARRAY_PTR(count)[i_rank-1-i]);
         if(l_count < 0) {
 	  l_count +=hs_dims[i];
         }
